Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(490)

Unified Diff: third_party/WebKit/Source/platform/heap/BlinkGCMemoryDumpProvider.cpp

Issue 1845543002: Rename Heap to ThreadHeap (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/heap/BlinkGCMemoryDumpProvider.cpp
diff --git a/third_party/WebKit/Source/platform/heap/BlinkGCMemoryDumpProvider.cpp b/third_party/WebKit/Source/platform/heap/BlinkGCMemoryDumpProvider.cpp
index e627183e10da1647abc245c42f10eb227950ecaa..eea1e747c6a08964d482adae8e10dee18a147253 100644
--- a/third_party/WebKit/Source/platform/heap/BlinkGCMemoryDumpProvider.cpp
+++ b/third_party/WebKit/Source/platform/heap/BlinkGCMemoryDumpProvider.cpp
@@ -26,7 +26,7 @@ void dumpMemoryTotals(blink::WebProcessMemoryDump* memoryDump)
dumpName.append("/allocated_objects");
WebMemoryAllocatorDump* objectsDump = memoryDump->createMemoryAllocatorDump(dumpName);
// Heap::markedObjectSize() can be underestimated if we're still in the
// process of lazy sweeping.
objectsDump->addScalar("size", "bytes", ProcessHeap::totalAllocatedObjectSize() + ProcessHeap::totalMarkedObjectSize());
}
@@ -58,7 +58,7 @@ bool BlinkGCMemoryDumpProvider::onMemoryDump(WebMemoryDumpLevelOfDetail levelOfD
// In the case of a detailed dump perform a mark-only GC pass to collect
// more detailed stats.
if (levelOfDetail == WebMemoryDumpLevelOfDetail::Detailed)
- Heap::collectGarbage(BlinkGC::NoHeapPointersOnStack, BlinkGC::TakeSnapshot, BlinkGC::ForcedGC);
+ ThreadHeap::collectGarbage(BlinkGC::NoHeapPointersOnStack, BlinkGC::TakeSnapshot, BlinkGC::ForcedGC);
dumpMemoryTotals(memoryDump);
if (m_isHeapProfilingEnabled) {
@@ -76,7 +76,7 @@ bool BlinkGCMemoryDumpProvider::onMemoryDump(WebMemoryDumpLevelOfDetail levelOfD
memoryDump->dumpHeapUsage(bytesByContext, overhead, "blink_gc");
}
// Merge all dumps collected by Heap::collectGarbage.
if (levelOfDetail == WebMemoryDumpLevelOfDetail::Detailed)
memoryDump->takeAllDumpsFrom(m_currentProcessMemoryDump.get());
return true;
@@ -26,7 +26,7 @@ void dumpMemoryTotals(blink::WebProcessMemoryDump* memoryDump)
dumpName.append("/allocated_objects");
WebMemoryAllocatorDump* objectsDump = memoryDump->createMemoryAllocatorDump(dumpName);
- // Heap::markedObjectSize() can be underestimated if we're still in the
+ // ThreadHeap::markedObjectSize() can be underestimated if we're still in the
// process of lazy sweeping.
objectsDump->addScalar("size", "bytes", ProcessHeap::totalAllocatedObjectSize() + ProcessHeap::totalMarkedObjectSize());
@@ -76,7 +76,7 @@ bool BlinkGCMemoryDumpProvider::onMemoryDump(WebMemoryDumpLevelOfDetail levelOfD
memoryDump->dumpHeapUsage(bytesByContext, overhead, "blink_gc");
}
- // Merge all dumps collected by Heap::collectGarbage.
+ // Merge all dumps collected by ThreadHeap::collectGarbage.
if (levelOfDetail == WebMemoryDumpLevelOfDetail::Detailed)
memoryDump->takeAllDumpsFrom(m_currentProcessMemoryDump.get());
« no previous file with comments | « third_party/WebKit/Source/platform/heap/BlinkGC.h ('k') | third_party/WebKit/Source/platform/heap/GarbageCollected.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698